SystemOrganization addCategory: #'Seaside-Tests-Development'!

!WAPackage class methodsFor: '*seaside-tests-development' stamp: 'jf 1/11/2009 14:32'!
seasideTestsDevelopment
	^ self new
		name: 'Seaside-Tests-Development';
		description: 'Unit tests for the package Seaside-Development.';
		addDependency: 'Seaside-Development';
		addDependency: 'Seaside-Tests-WebTools';
		yourself! !

TestCase subclass: #WADebugErrorHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADebugErrorHandlerTest commentStamp: 'jf 9/19/2008 19:32' prior: 0!
This isn't really a unit test of WADebugErrorHandler but rather a test that tries to replicate a simple version of the same error handling behaviour upon which the error handler depends. The error handler itself would be hard to test because it opens a debugger as its first action.

This should at least help confirm that the assumptions that were in place when writing the handler on Squeak hold true on other platforms.!

!WADebugErrorHandlerTest methodsFor: 'private' stamp: 'jf 9/19/2008 19:03'!
handleException: anException debuggerSimulation: debugBlock
	debugBlock ifCurtailed: [^  #aborted].
	anException resume! !

!WADebugErrorHandlerTest methodsFor: 'private' stamp: 'jf 1/22/2009 02:43'!
simulateWithDebugBlock: debugBlock progress: desiredProgress result: desiredResult
	"Set up a known working mechanism similar to the error handler so we can
	test whether the underlying system works the same way as on Squeak
	where WADebugErrorHandler was originally developed."
	
	| progress semaphore result |
	progress := OrderedCollection new.
	
	semaphore := WAPlatform current semaphoreClass new.
	
	[[ result := [
		progress add: #a.
		1/0.
		progress add: #b.
		#resumed ]
			on: Error
			do: [ :e |
				progress add: #c.
				self
					handleException: e
					debuggerSimulation: [
						progress add: #d.
						debugBlock value.
						progress add: #e ] ]
	] ensure: [ semaphore signal ] ] fork.

	semaphore wait.
	
	self assert: progress asArray = desiredProgress asArray.
	self assert: result = desiredResult.! !

!WADebugErrorHandlerTest methodsFor: 'testing' stamp: 'jf 9/19/2008 19:25'!
testMechanismAbort
	"Test if things behave as expected when simulating a Debugger being closed
	(in other words, the process being terminated)."
	
	self
		simulateWithDebugBlock: [Processor activeProcess terminate]
		progress: #(a c d)
		result: #aborted! !

!WADebugErrorHandlerTest methodsFor: 'testing' stamp: 'jf 9/19/2008 19:29'!
testMechanismProceed
	"Test if things behave as expected when simulating a Debugger being proceeded
	(in other words, the process being terminated)."
	
	self
		simulateWithDebugBlock: [nil]
		progress: #(a c d e b)
		result: #resumed! !

TestCase subclass: #WADevelopmentPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

TestCase subclass: #WAWalkbackTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WAWalkbackTest methodsFor: 'testing' stamp: 'jf 3/3/2009 22:25'!
testFrameCount
	| walkback |
	[WATestError signal: 'foo']
		on: WATestError
		do: [ :e | walkback := WAWalkback current exception: e ].

	self assert: walkback frameCount > 0! !
